@@ -7,6 +7,6 @@ DIR=jcodings-$2
 git clone http://github.com/jruby/jcodings.git $DIR
 (cd $DIR && git checkout $2)
 
-tar cfz jcodings_$2.orig.tar.gz --exclude .git $DIR
+tar cfz ../jcodings_$2.orig.tar.gz --exclude .git $DIR
 
 rm -rf $DIR ../$2
